from setuptools import setup

setup(name='deos.org',
      version='0.1',
      description='deos.org',
      url='https://github.com/desantis/python-deos.org',
      author='Andrew T. DeSantis',
      author_email='atd@deos.org',
      license='MIT',
      packages=['deos.org'],
      zip_safe=False)
